.. _writers:

=======
Writers
=======

This section describes classes for writing data in various formats, such as CSV or Excel files.

Writer
======

.. autoclass:: nuaal.Writers.Writer
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

ExcelWriter
===========

.. autoclass:: nuaal.Writers.ExcelWriter
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

